@@ -134,6 +134,7 @@ Rcpp::List cDDP(arma::vec data,
   int start_s = clock();
   int current_s;
 
+  double temp2;
   //
   // STARTING
   // MAIN
@@ -143,12 +144,7 @@ Rcpp::List cDDP(arma::vec data,
   for(arma::uword iter = 0; iter < niter; iter++){
 
     //clean parameter objects
-    para_clean_DDP(mu,
-                    s2,
-                    clust,
-                    group,
-                    group_log,
-                    ngr);
+    para_clean_DDP(mu, s2, clust, group, group_log, ngr);
 
     // sample the probability vector
     // from Dirichlet distribution
@@ -162,48 +158,23 @@ Rcpp::List cDDP(arma::vec data,
       } else {
         ptilde(g).resize(1);
         double temp = arma::randg(1, arma::distr_param(1.0, 1.0))[0];
-        double temp2 = arma::randg(1, arma::distr_param(mass * wei, 1.0))[0];
+        if(g != 0){
+          temp2 = arma::randg(1, arma::distr_param(mass * wei, 1.0))[0];
+        } else {
+          temp2 = arma::randg(1, arma::distr_param(mass * (1 - wei), 1.0))[0];
+        }
         ptilde(g)(0) =  temp2 / ( temp + temp2);
       }
-
     }
 
     // update w
-    update_w_DDP(w,
-                  mass,
-                  wei,
-                  n_approx_unif,
-                  group_log,
-                  clust,
-                  group,
-                  temp_proc_cum,
-                  ngr);
+    update_w_DDP(w, mass, wei, n_approx_unif, group_log, clust, group, temp_proc_cum, ngr);
 
     // acceleration step
-    accelerate_DDP(data,
-                    group,
-                    group_log,
-                    mu,
-                    s2,
-                    clust,
-                    m0,
-                    k0,
-                    a0,
-                    b0,
-                    ngr);
+    accelerate_DDP(data, group, group_log, mu, s2, clust, m0, k0, a0, b0, ngr);
 
     // simulate the required values
-    simu_trunc_DDP(mutemp,
-                    s2temp,
-                    freqtemp,
-                    mass,
-                    wei,
-                    m0,
-                    k0,
-                    a0,
-                    b0,
-                    napprox,
-                    ngr);
+    simu_trunc_DDP(mutemp, s2temp, freqtemp, mass, wei, m0, k0, a0, b0, napprox, ngr);
 
     // joint the existent parameters with
     // the simulated new ones
@@ -222,7 +193,7 @@ Rcpp::List cDDP(arma::vec data,
 
         mujoin(g) = mutemp(g);
         s2join(g) = s2temp(g);
-        probjoin(g) = freqtemp(g) / napprox;
+        probjoin(g) = freqtemp(g) / napprox * ptilde(g)(0);
       }
 
     }
@@ -238,17 +209,8 @@ Rcpp::List cDDP(arma::vec data,
 
 
     // update cluster allocations
-    clust_update_DDP(data,
-                      group,
-                      group_log,
-                      mujoin_complete,
-                      s2join_complete,
-                      probjoin_complete,
-                      clust,
-                      temp_proc_cum,
-                      max_val,
-                      iter,
-                      ngr);
+    clust_update_DDP(data, group, group_log, mujoin_complete, s2join_complete,
+                     probjoin_complete, clust, temp_proc_cum, max_val, iter, ngr);
 
     mu = mujoin;
     s2 = s2join;
@@ -263,7 +225,6 @@ Rcpp::List cDDP(arma::vec data,
       // compute the density for each urn
       for(arma::uword g = 0; g < ngr; g++){
         if(out_dens){
-
           dens.col(g) = eval_density(grid, mujoin_complete(g),
                    s2join_complete(g), probjoin_complete(g));
         }
